Skip to contents

Per-case summary of a traces object

Usage

# S3 method for class 'traces'
summary(object, ...)

Arguments

object

A traces object.

...

Unused.

Value

A data frame with one row per case giving the number of events and the number of distinct activities.