traces
R/traces.R
summary.traces.Rd
Per-case summary of a traces object
# S3 method for class 'traces' summary(object, ...)
A traces object.
Unused.
A data frame with one row per case giving the number of events and the number of distinct activities.